Module: RuboCop::Cop::Sidekiq::ProcessedSourcePath
- Included in:
- JobFileLocation, JobFileNaming
- Defined in:
- lib/rubocop/cop/sidekiq/mixin/processed_source_path.rb
Overview
Shared helpers for working with the current file path.
Shared helpers for working with the current file path.